<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it_IT">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Seleziona uno o più dispositivi</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Webcam</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Passa a Finestra</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Passa a Schermo Intero</translation>
    </message>
</context>
<context>
    <name>QvkCiscoFinishDialog</name>
    <message>
        <source>The setup was successful.</source>
        <translation>La configurazione ha avuto successo.</translation>
    </message>
    <message>
        <source>Close this window and start vokoscreenNG again.</source>
        <translation>Chiudere questa finestra e riavviare vokoscreenNG.</translation>
    </message>
    <message>
        <source>Have fun with vokoscreenNG</source>
        <translation>Buon divertimento con vokoscreenNG</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Seleziona uno o più dispositivi</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Nessun filemanager trovato.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Installa un filemanager.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Attenzione</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>Registrazione non è stata avviata. Spazio disco insufficiente.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Limite spazio disco libero raggiunto</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Limite di spazio disco libero</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>Registrazione interrotta. Spazio disco insufficiente</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Schermo intero</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Finestra</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
        <translation>Filemanager non trovato.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Si prega di installare un filemanager.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Codice sorgente</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Pagina iniziale</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Traduzioni</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Fai una donazione</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Seleziona uno o più dispositivi</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Area</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise_wl</name>
    <message>
        <source>Area</source>
        <translation>Area</translation>
    </message>
</context>
<context>
    <name>QvkSnapshot</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Filemanager non trovato.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Si prega di installare un filemanager.</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Inizia</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Ferma</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continua</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Ingrandimento</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Inizia</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Interrompi</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continua</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Ingrandisci</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Finestra di dialogo Impostazioni fotocamera</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Capovolgi orizzontale</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Capovolgi verticale</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Inverti</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grigio</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Bianco e nero</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Rimuovi bordo finestra</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Impostazioni camera</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Area</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Ripristina</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Ingrandisci</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Avvio ritardo di</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Dimensioni video:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Spazio disco libero:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informazione</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Tempo di registrazione:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Fotogrammi</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Codifica video</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato video</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Codificatore audio</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Qualità</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Non registrare il cursore del mouse</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Ora</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minuto</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Avvia il tempo</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Ferma la registrazione dopo</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Ore</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minuti</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Secondi</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Salva in</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Limite di spazio disco libero</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Mostra nel vassoio di sistema</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Secondi di attesa prima di registrare</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Cerca aggiornamenti</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Disponibile</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Non disponibile</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Avvia</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Ferma</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continua</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Riproduci</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Cartella</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Inverti</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grigio</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Riproduci ultima registrazione</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Apri cartella</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Ridotto a icona durante la registrazione</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Avvia a icona</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Capovolgi orizzontale</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Capovolgi verticale</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Bianco e nero</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Rimuovi bordo finestra</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Fai una donazione</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Ripristina tutte le impostazioni al prossimo avvio</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Copyright e licenza immagini</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Registra Schermo</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Lettore</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Registro eventi</translation>
    </message>
    <message>
        <source>Automatically</source>
        <translation>Automaticamente</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>Crea immagini delle schede</translation>
    </message>
    <message>
        <source>License information</source>
        <translation>Informazioni sulla licenza</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>Acceso</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>Spento</translation>
    </message>
    <message>
        <source>Global keyboard shortcuts</source>
        <translation>Scorciatoie da tastiera globali</translation>
    </message>
    <message>
        <source>Assigned shortcut keys.</source>
        <translation>Tasti scorciatoia assegnati.</translation>
    </message>
    <message>
        <source>Keyboard shortcut not assigned or assigned more than once.</source>
        <translation>Scorciatoia da tastiera non assegnata o assegnata più volte.</translation>
    </message>
    <message>
        <source>If it shows assigned but does not work, it is being used by another program.</source>
        <translation>Se mostra l&apos;assegnamento ma non funziona, significa che è usata da qualche altro programma.</translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation>Snapshot</translation>
    </message>
    <message>
        <source>Imagepath</source>
        <translation>Percorso immagine</translation>
    </message>
    <message>
        <source>Hide this window</source>
        <translation>Nascondi questa finestra</translation>
    </message>
    <message>
        <source>Seconds wait before recording</source>
        <translation>Secondi di attesa prima di registrare</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Copyright e licenza immagini</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Riproduci</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Ferma</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Apri file</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Schermo intero</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Fermo immagine precedente</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Fermo immagine successivo</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Silenzia</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Sposta menu</translation>
    </message>
</context>
</TS>